@@ -32,6 +32,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QVector>
 // std
 #include <functional>
+#include <memory>
 
 // TODO: Cleanup the order of things in this .h file
 
@@ -47,6 +48,7 @@ namespace KWin
 
 namespace Xcb
 {
+class Tree;
 class Window;
 }
 
@@ -324,8 +326,8 @@ public:
 
     void focusToNull(); // SELI TODO: Public?
 
-    void clientShortcutUpdated(Client* c);
-    bool shortcutAvailable(const QKeySequence &cut, Client* ignore = NULL) const;
+    void clientShortcutUpdated(AbstractClient* c);
+    bool shortcutAvailable(const QKeySequence &cut, AbstractClient* ignore = NULL) const;
     bool globalShortcutsDisabled() const;
     void disableGlobalShortcutsForClient(bool disable);
 
@@ -365,11 +367,27 @@ public:
     void registerEventFilter(X11EventFilter *filter);
     void unregisterEventFilter(X11EventFilter *filter);
 
+    void markXStackingOrderAsDirty();
+
+    void quickTileWindow(QuickTileMode mode);
+
+    enum Direction {
+        DirectionNorth,
+        DirectionEast,
+        DirectionSouth,
+        DirectionWest
+    };
+    void switchWindow(Direction direction);
+
+    ShortcutDialog *shortcutDialog() const {
+        return client_keys_dialog;
+    }
+
 public Q_SLOTS:
     void performWindowOperation(KWin::AbstractClient* c, Options::WindowOperation op);
     // Keybindings
     //void slotSwitchToWindow( int );
-    void slotWindowToDesktop();
+    void slotWindowToDesktop(uint i);
 
     //void slotWindowToListPosition( int );
     void slotSwitchToScreen();
@@ -397,19 +415,6 @@ public Q_SLOTS:
     void slotWindowGrowVertical();
     void slotWindowShrinkHorizontal();
     void slotWindowShrinkVertical();
-    void slotWindowQuickTileLeft();
-    void slotWindowQuickTileRight();
-    void slotWindowQuickTileTop();
-    void slotWindowQuickTileBottom();
-    void slotWindowQuickTileTopLeft();
-    void slotWindowQuickTileTopRight();
-    void slotWindowQuickTileBottomLeft();
-    void slotWindowQuickTileBottomRight();
-
-    void slotSwitchWindowUp();
-    void slotSwitchWindowDown();
-    void slotSwitchWindowRight();
-    void slotSwitchWindowLeft();
 
     void slotIncreaseWindowOpacity();
     void slotLowerWindowOpacity();
@@ -498,13 +503,6 @@ private:
     void initShortcut(const QString &actionName, const QString &description, const QKeySequence &shortcut,
                       Slot slot, const QVariant &data = QVariant());
     void setupWindowShortcut(AbstractClient* c);
-    enum Direction {
-        DirectionNorth,
-        DirectionEast,
-        DirectionSouth,
-        DirectionWest
-    };
-    void switchWindow(Direction direction);
     bool switchWindow(AbstractClient *c, Direction direction, QPoint curPos, int desktop);
 
     void propagateClients(bool propagate_new_clients);   // Called only from updateStackingOrder
@@ -546,6 +544,8 @@ private:
     static NET::WindowType txtToWindowType(const char* txt);
     static bool sessionInfoWindowTypeMatch(Client* c, SessionInfo* info);
 
+    void updateXStackingOrder();
+
     AbstractClient* active_client;
     AbstractClient* last_active_client;
     AbstractClient* most_recently_raised; // Used ONLY by raiseOrLowerClient()
@@ -565,8 +565,8 @@ private:
     ToplevelList unconstrained_stacking_order; // Topmost last
     ToplevelList stacking_order; // Topmost last
     bool force_restacking;
-    mutable ToplevelList x_stacking; // From XQueryTree()
-    mutable bool x_stacking_dirty;
+    ToplevelList x_stacking; // From XQueryTree()
+    std::unique_ptr<Xcb::Tree> m_xStackingQueryTree;
     QList<AbstractClient*> should_get_focus; // Last is most recent
     QList<AbstractClient*> attention_chain;
 
@@ -575,6 +575,7 @@ private:
     GroupList groups;
 
     bool was_user_interaction;
+    QScopedPointer<X11EventFilter> m_wasUserInteractionFilter;
     bool session_saving;
     int session_active_client;
     int session_desktop;
@@ -623,6 +624,7 @@ private:
 
     QList<X11EventFilter *> m_eventFilters;
     QList<X11EventFilter *> m_genericEventFilters;
+    QScopedPointer<X11EventFilter> m_movingClientFilter;
 
 private:
     friend bool performTransiencyCheck();
@@ -695,11 +697,6 @@ inline const ToplevelList& Workspace::stackingOrder() const
     return stacking_order;
 }
 
-inline void Workspace::setWasUserInteraction()
-{
-    was_user_interaction = true;
-}
-
 inline bool Workspace::wasUserInteraction() const
 {
     return was_user_interaction;
